@@ -59,7 +59,6 @@ class ParticleTrajectories:
     def __init__(
         self, outputs, indices, fields=None, suppress_logging=False, ptype=None
     ):
-
         indices.sort()  # Just in case the caller wasn't careful
         self.field_data = YTFieldData()
         self.data_series = outputs
@@ -324,7 +323,6 @@ class ParticleTrajectories:
 
         Examples
         --------
-        >>> from yt.mods import *
         >>> import matplotlib.pyplot as plt
         >>> trajs = ParticleTrajectories(my_fns, indices)
         >>> traj = trajs.trajectory_from_index(indices[0])
@@ -339,7 +337,7 @@ class ParticleTrajectories:
         if not np.any(mask):
             print("The particle index %d is not in the list!" % (index))
             raise IndexError
-        fields = [field for field in sorted(self.field_data.keys())]
+        fields = sorted(self.field_data.keys())
         traj = {}
         traj["particle_time"] = self.times
         traj["particle_index"] = index
@@ -364,7 +362,7 @@ class ParticleTrajectories:
         >>> trajs = ParticleTrajectories(my_fns, indices)
         >>> trajs.write_out("orbit_trajectory")
         """
-        fields = [field for field in sorted(self.field_data.keys())]
+        fields = sorted(self.field_data.keys())
         num_fields = len(fields)
         first_str = "# particle_time\t" + "\t".join(fields) + "\n"
         template_str = "%g\t" * num_fields + "%g\n"
@@ -404,6 +402,6 @@ class ParticleTrajectories:
         fid.create_dataset("particle_indices", dtype=np.int64, data=self.indices)
         fid.close()
         self.times.write_hdf5(filename, dataset_name="particle_times")
-        fields = [field for field in sorted(self.field_data.keys())]
+        fields = sorted(self.field_data.keys())
         for field in fields:
             self[field].write_hdf5(filename, dataset_name=f"{field}")
