@@ -3,8 +3,9 @@ import tempfile
 from unittest import mock
 
 import numpy as np
+from numpy.testing import assert_equal
 
-from yt.testing import assert_equal, assert_rel_equal, fake_amr_ds, fake_random_ds
+from yt.testing import assert_rel_equal, fake_amr_ds, fake_random_ds
 from yt.units.unit_object import Unit
 
 LENGTH_UNIT = 2.0
