@@ -1,16 +1,18 @@
 import contextlib
 import inspect
 import re
-from typing import Optional, Tuple, Union
+from typing import Optional, Union
 
 from more_itertools import always_iterable
 
 import yt.units.dimensions as ytdims
 from yt._maintenance.deprecation import issue_deprecation_warning
+from yt._typing import FieldKey
 from yt.funcs import iter_fields, validate_field_key
 from yt.units.unit_object import Unit  # type: ignore
 from yt.utilities.exceptions import YTFieldNotFound
 from yt.utilities.logger import ytLogger as mylog
+from yt.visualization._commons import _get_units_label
 
 from .field_detector import FieldDetector
 from .field_exceptions import (
@@ -109,7 +111,7 @@ class DerivedField:
 
     def __init__(
         self,
-        name: Tuple[str, str],
+        name: FieldKey,
         sampling_type,
         function,
         units: Optional[Union[str, bytes, Unit]] = None,
@@ -125,7 +127,6 @@ class DerivedField:
         nodal_flag=None,
         *,
         alias: Optional["DerivedField"] = None,
-        particle_type=None,
     ):
         validate_field_key(name)
         self.name = name
@@ -133,14 +134,6 @@ class DerivedField:
         self.display_name = display_name
         self.not_in_all = not_in_all
         self.display_field = display_field
-        if particle_type is not None:
-            issue_deprecation_warning(
-                "The 'particle_type' keyword argument is deprecated. "
-                "Please use sampling_type='particle' instead.",
-                since="3.2",
-                removal="4.2",
-            )
-            sampling_type = "particle"
         self.sampling_type = sampling_type
         self.vector_field = vector_field
         self.ds = ds
@@ -171,9 +164,8 @@ class DerivedField:
             self.units = units.decode("utf-8")
         else:
             raise FieldUnitsError(
-                "Cannot handle units '%s' (type %s). "
-                "Please provide a string or Unit "
-                "object." % (units, type(units))
+                f"Cannot handle units {units!r} (type {type(units)}). "
+                "Please provide a string or Unit object."
             )
         if output_units is None:
             output_units = self.units
@@ -322,7 +314,7 @@ class DerivedField:
                 units = Unit(self.units)
         # Add unit label
         if not units.is_dimensionless:
-            data_label += r"\ \ \left(%s\right)" % (units.latex_representation())
+            data_label += _get_units_label(units.latex_representation()).strip("$")
 
         data_label += r"$"
         return data_label
@@ -343,7 +335,7 @@ class DerivedField:
         return self._shared_aliases_list is other._shared_aliases_list
 
     @property
-    def alias_name(self) -> Optional[Tuple[str, str]]:
+    def alias_name(self) -> Optional[FieldKey]:
         if self.is_alias:
             return self._shared_aliases_list[0].name
         return None
@@ -402,7 +394,6 @@ class DerivedField:
         p = re.compile("_p[0-9]+_")
         m = p.search(self.name[1])
         if m is not None:
-
             # Find the ionization state
             pstr = m.string[m.start() + 1 : m.end() - 1]
             segments = self.name[1].split("_")
