@@ -1,16 +1,16 @@
+import sys
 from collections import UserDict
 from collections.abc import Callable
-from numbers import Number as numeric_type
-from typing import Optional, Tuple
+from typing import Dict, List, Optional, Tuple
 
-import numpy as np
 from unyt.exceptions import UnitConversionError
 
-from yt._typing import KnownFieldsT
+from yt._maintenance.deprecation import issue_deprecation_warning
+from yt._typing import FieldKey, FieldName, FieldType, KnownFieldsT
 from yt.config import ytcfg
 from yt.fields.field_exceptions import NeedsConfiguration
 from yt.funcs import mylog, obj_length, only_on_root
-from yt.geometry.geometry_handler import is_curvilinear
+from yt.geometry.api import Geometry
 from yt.units.dimensions import dimensionless  # type: ignore
 from yt.units.unit_object import Unit  # type: ignore
 from yt.utilities.exceptions import (
@@ -20,7 +20,7 @@ from yt.utilities.exceptions import (
 )
 
 from .derived_field import DeprecatedFieldFunc, DerivedField, NullFunc, TranslationFunc
-from .field_plugin_registry import field_plugins
+from .field_plugin_registry import FunctionName, field_plugins
 from .particle_fields import (
     add_union_field,
     particle_deposition_functions,
@@ -30,6 +30,11 @@ from .particle_fields import (
     standard_particle_fields,
 )
 
+if sys.version_info >= (3, 11):
+    from typing import assert_never
+else:
+    from typing_extensions import assert_never
+
 
 class FieldInfoContainer(UserDict):
     """
@@ -43,23 +48,33 @@ class FieldInfoContainer(UserDict):
     fallback = None
     known_other_fields: KnownFieldsT = ()
     known_particle_fields: KnownFieldsT = ()
-    extra_union_fields: Tuple[Tuple[str, str], ...] = ()
+    extra_union_fields: Tuple[FieldKey, ...] = ()
 
-    def __init__(self, ds, field_list, slice_info=None):
+    def __init__(self, ds, field_list: List[FieldKey], slice_info=None):
         super().__init__()
-        self._show_field_errors = []
+        self._show_field_errors: List[Exception] = []
         self.ds = ds
         # Now we start setting things up.
         self.field_list = field_list
         self.slice_info = slice_info
-        self.field_aliases = {}
-        self.species_names = []
-        if ds is not None and is_curvilinear(ds.geometry):
-            self.curvilinear = True
-        else:
-            self.curvilinear = False
+        self.field_aliases: Dict[FieldKey, FieldKey] = {}
+        self.species_names: List[FieldName] = []
         self.setup_fluid_aliases()
 
+    @property
+    def curvilinear(self) -> bool:
+        issue_deprecation_warning(
+            "FieldInfoContainer.curvilinear attribute is deprecated. "
+            "Please compare the internal dataset geometry directly to known Geometry enum members instead. ",
+            since="4.2",
+        )
+        geometry = self.ds.geometry
+        return (
+            geometry is Geometry.POLAR
+            or geometry is Geometry.CYLINDRICAL
+            or geometry is Geometry.SPHERICAL
+        )
+
     def setup_fluid_fields(self):
         pass
 
@@ -181,6 +196,13 @@ class FieldInfoContainer(UserDict):
                     (ptype, alias_name),
                 )
             )
+            if "particle_position_" in alias_name:
+                new_aliases.append(
+                    (
+                        (ftype, alias_name),
+                        (ptype, alias_name),
+                    )
+                )
             new_aliases.append(
                 (
                     (ptype, uni_alias_name),
@@ -189,22 +211,43 @@ class FieldInfoContainer(UserDict):
             )
             for alias, source in new_aliases:
                 self.alias(alias, source)
+        self.alias((ftype, "particle_position"), (ptype, "particle_position"))
+        self.alias((ftype, "particle_mass"), (ptype, "particle_mass"))
 
     # Collect the names for all aliases if geometry is curvilinear
-    def get_aliases_gallery(self):
-        aliases_gallery = []
+    def get_aliases_gallery(self) -> List[FieldName]:
+        aliases_gallery: List[FieldName] = []
         known_other_fields = dict(self.known_other_fields)
-        if self.curvilinear:
+
+        if self.ds is None:
+            return aliases_gallery
+
+        geometry: Geometry = self.ds.geometry
+        if (
+            geometry is Geometry.POLAR
+            or geometry is Geometry.CYLINDRICAL
+            or geometry is Geometry.SPHERICAL
+        ):
+            aliases: List[FieldName]
             for field in sorted(self.field_list):
                 if field[0] in self.ds.particle_types:
                     continue
                 args = known_other_fields.get(field[1], ("", [], None))
                 units, aliases, display_name = args
-                for alias in aliases:
-                    aliases_gallery.append(alias)
+                aliases_gallery.extend(aliases)
+        elif (
+            geometry is Geometry.CARTESIAN
+            or geometry is Geometry.GEOGRAPHIC
+            or geometry is Geometry.INTERNAL_GEOGRAPHIC
+            or geometry is Geometry.SPECTRAL_CUBE
+        ):
+            # nothing to do
+            pass
+        else:
+            assert_never(geometry)
         return aliases_gallery
 
-    def setup_fluid_aliases(self, ftype="gas"):
+    def setup_fluid_aliases(self, ftype: FieldType = "gas") -> None:
         known_other_fields = dict(self.known_other_fields)
 
         # For non-Cartesian geometry, convert alias of vector fields to
@@ -212,7 +255,7 @@ class FieldInfoContainer(UserDict):
         aliases_gallery = self.get_aliases_gallery()
 
         for field in sorted(self.field_list):
-            if not isinstance(field, tuple):
+            if not isinstance(field, tuple) or len(field) != 2:
                 raise RuntimeError
             if field[0] in self.ds.particle_types:
                 continue
@@ -223,7 +266,7 @@ class FieldInfoContainer(UserDict):
                 try:
                     node = ytcfg.get("fields", *field).as_dict()
                 except KeyError:
-                    node = dict()
+                    node = {}
 
                 units = node.get("units", "")
                 aliases = node.get("aliases", [])
@@ -233,30 +276,17 @@ class FieldInfoContainer(UserDict):
             # field *name* is in there, then the field *tuple*.
             units = self.ds.field_units.get(field[1], units)
             units = self.ds.field_units.get(field, units)
-            if not isinstance(units, str) and args[0] != "":
-                units = f"(({args[0]})*{units})"
-            if (
-                isinstance(units, (numeric_type, np.number, np.ndarray))
-                and args[0] == ""
-                and units != 1.0
-            ):
-                mylog.warning(
-                    "Cannot interpret units: %s * %s, setting to dimensionless.",
-                    units,
-                    args[0],
-                )
-                units = ""
-            elif units == 1.0:
-                units = ""
             self.add_output_field(
                 field, sampling_type="cell", units=units, display_name=display_name
             )
             axis_names = self.ds.coordinates.axis_order
+            geometry: Geometry = self.ds.geometry
             for alias in aliases:
                 if (
-                    self.curvilinear
-                ):  # For non-Cartesian geometry, convert vector aliases
-
+                    geometry is Geometry.POLAR
+                    or geometry is Geometry.CYLINDRICAL
+                    or geometry is Geometry.SPHERICAL
+                ):
                     if alias[-2:] not in ["_x", "_y", "_z"]:
                         to_convert = False
                     else:
@@ -272,6 +302,16 @@ class FieldInfoContainer(UserDict):
                             alias = f"{alias[:-2]}_{axis_names[1]}"
                         elif alias[-2:] == "_z":
                             alias = f"{alias[:-2]}_{axis_names[2]}"
+                elif (
+                    geometry is Geometry.CARTESIAN
+                    or geometry is Geometry.GEOGRAPHIC
+                    or geometry is Geometry.INTERNAL_GEOGRAPHIC
+                    or geometry is Geometry.SPECTRAL_CUBE
+                ):
+                    # nothing to do
+                    pass
+                else:
+                    assert_never(geometry)
                 self.alias((ftype, alias), field)
 
     @staticmethod
@@ -305,7 +345,7 @@ class FieldInfoContainer(UserDict):
 
     def add_field(
         self,
-        name: Tuple[str, str],
+        name: FieldKey,
         function: Callable,
         sampling_type: str,
         *,
@@ -366,7 +406,7 @@ class FieldInfoContainer(UserDict):
         else:
             raise ValueError(f"Expected name to be a tuple[str, str], got {name}")
 
-    def load_all_plugins(self, ftype: Optional[str] = "gas"):
+    def load_all_plugins(self, ftype: Optional[str] = "gas") -> None:
         if ftype is None:
             return
         mylog.debug("Loading field plugins for field type: %s.", ftype)
@@ -376,11 +416,13 @@ class FieldInfoContainer(UserDict):
             only_on_root(mylog.debug, "Loaded %s (%s new fields)", n, len(loaded))
         self.find_dependencies(loaded)
 
-    def load_plugin(self, plugin_name, ftype="gas", skip_check=False):
-        if callable(plugin_name):
-            f = plugin_name
-        else:
-            f = field_plugins[plugin_name]
+    def load_plugin(
+        self,
+        plugin_name: FunctionName,
+        ftype: FieldType = "gas",
+        skip_check: bool = False,
+    ):
+        f = field_plugins[plugin_name]
         orig = set(self.items())
         f(self, ftype, slice_info=self.slice_info)
         loaded = [n for n, v in set(self.items()).difference(orig)]
@@ -406,8 +448,8 @@ class FieldInfoContainer(UserDict):
 
     def alias(
         self,
-        alias_name: Tuple[str, str],
-        original_name: Tuple[str, str],
+        alias_name: FieldKey,
+        original_name: FieldKey,
         units: Optional[str] = None,
         deprecate: Optional[Tuple[str, Optional[str]]] = None,
     ):
@@ -416,9 +458,9 @@ class FieldInfoContainer(UserDict):
 
         Parameters
         ----------
-        alias_name : Tuple[str, str]
+        alias_name : tuple[str, str]
             The new field name.
-        original_name : Tuple[str, str]
+        original_name : tuple[str, str]
             The field to be aliased.
         units : str
            A plain text string encoding the unit.  Powers must be in
@@ -564,7 +606,6 @@ class FieldInfoContainer(UserDict):
         return keys
 
     def check_derived_fields(self, fields_to_check=None):
-
         # The following exceptions lists were obtained by expanding an
         # all-catching `except Exception`.
         # We define
