@@ -30,6 +30,7 @@ sph_whitelist_fields = (
     "metallicity",
     "thermal_energy",
     "smoothing_length",
+    "star_formation_rate",
     "H_fraction",
     "He_fraction",
     "C_fraction",
@@ -67,7 +68,6 @@ def _field_concat(fname):
     def _AllFields(field, data):
         v = []
         for ptype in data.ds.particle_types:
-            data.ds._last_freq = (ptype, None)
             if ptype == "all" or ptype in data.ds.known_filters:
                 continue
             v.append(data[ptype, fname].copy())
@@ -81,7 +81,6 @@ def _field_concat_slice(fname, axi):
     def _AllFields(field, data):
         v = []
         for ptype in data.ds.particle_types:
-            data.ds._last_freq = (ptype, None)
             if ptype == "all" or ptype in data.ds.known_filters:
                 continue
             v.append(data[ptype, fname][:, axi])
@@ -240,7 +239,6 @@ def particle_deposition_functions(ptype, coord_name, mass_name, registry):
 
 
 def particle_scalar_functions(ptype, coord_name, vel_name, registry):
-
     # Now we have to set up the various velocity and coordinate things.  In the
     # future, we'll actually invert this and use the 3-component items
     # elsewhere, and stop using these.
@@ -273,7 +271,6 @@ def particle_scalar_functions(ptype, coord_name, vel_name, registry):
 
 
 def particle_vector_functions(ptype, coord_names, vel_names, registry):
-
     unit_system = registry.ds.unit_system
 
     # This will column_stack a set of scalars to create vector fields.
