@@ -8,6 +8,7 @@ from yt.data_objects.index_subobjects.grid_patch import AMRGridPatch
 from yt.data_objects.static_output import Dataset
 from yt.fields.magnetic_field import get_magnetic_normalization
 from yt.funcs import mylog, sglob
+from yt.geometry.api import Geometry
 from yt.geometry.geometry_handler import YTDataChunk
 from yt.geometry.grid_geometry_handler import GridIndex
 from yt.utilities.chemical_formulas import compute_mu
@@ -119,7 +120,6 @@ def parse_line(line, grid):
 
 
 class AthenaHierarchy(GridIndex):
-
     grid = AthenaGrid
     _dataset_type = "athena"
     _data_file = None
@@ -378,9 +378,7 @@ class AthenaHierarchy(GridIndex):
             self.grid_filenames = new_gridfilenames
             self.grid_left_edge = self.ds.arr(gle_all, "code_length")
             self.grid_right_edge = self.ds.arr(gre_all, "code_length")
-            self.grid_dimensions = np.array(
-                [shape for shape in shapes_all], dtype="int32"
-            )
+            self.grid_dimensions = np.array(list(shapes_all), dtype="int32")
             gdds = (self.grid_right_edge - self.grid_left_edge) / self.grid_dimensions
             glis = np.round(
                 (self.grid_left_edge - self.ds.domain_left_edge) / gdds
@@ -625,7 +623,7 @@ class AthenaDataset(Dataset):
             self.parameters["Gamma"] = self.specified_parameters["gamma"]
         else:
             self.parameters["Gamma"] = 5.0 / 3.0
-        self.geometry = self.specified_parameters.get("geometry", "cartesian")
+        self.geometry = Geometry(self.specified_parameters.get("geometry", "cartesian"))
         self._handle.close()
         self.mu = self.specified_parameters.get(
             "mu", compute_mu(self.default_species_fields)
