@@ -1,6 +1,6 @@
 import json
-import sys
 import time
+from functools import cached_property
 
 import numpy as np
 
@@ -9,11 +9,6 @@ from yt.frontends.sph.fields import SPHFieldInfo
 from yt.geometry.particle_geometry_handler import ParticleIndex
 from yt.utilities.on_demand_imports import _requests as requests
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from yt._maintenance.backports import cached_property
-
 
 class HTTPParticleFile(ParticleFile):
     pass
