@@ -1,15 +1,15 @@
 import abc
 import weakref
+from functools import cached_property
 from numbers import Number
-from typing import Tuple
+from typing import Optional, Tuple
 
 import numpy as np
-from packaging.version import Version
 
-from yt.funcs import fix_unitary, is_sequence, validate_width_tuple
+from yt._typing import AxisOrder
+from yt.funcs import fix_unitary, is_sequence, parse_center_array, validate_width_tuple
 from yt.units.yt_array import YTArray, YTQuantity
 from yt.utilities.exceptions import YTCoordinateNotImplemented, YTInvalidWidthError
-from yt.visualization._commons import MPL_VERSION
 
 
 def _unknown_coord(field, data):
@@ -132,10 +132,14 @@ def validate_sequence_width(width, ds, unit=None):
 
 class CoordinateHandler(abc.ABC):
     name: str
+    _default_axis_order: AxisOrder
 
-    def __init__(self, ds, ordering):
+    def __init__(self, ds, ordering: Optional[AxisOrder] = None):
         self.ds = weakref.proxy(ds)
-        self.axis_order = ordering
+        if ordering is not None:
+            self.axis_order = ordering
+        else:
+            self.axis_order = self._default_axis_order
 
     @abc.abstractmethod
     def setup_fields(self):
@@ -181,98 +185,57 @@ class CoordinateHandler(abc.ABC):
     def convert_from_spherical(self, coord):
         pass
 
-    _data_projection = None
-
-    @property
+    @cached_property
     def data_projection(self):
-        if self._data_projection is not None:
-            return self._data_projection
-        dpj = {}
-        for ax in self.axis_order:
-            dpj[ax] = None
-        self._data_projection = dpj
-        return dpj
+        return {ax: None for ax in self.axis_order}
 
-    _data_transform = None
-
-    @property
+    @cached_property
     def data_transform(self):
-        if self._data_transform is not None:
-            return self._data_transform
-        dtx = {}
-        for ax in self.axis_order:
-            dtx[ax] = None
-        self._data_transform = dtx
-        return dtx
+        return {ax: None for ax in self.axis_order}
 
-    _axis_name = None
-
-    @property
+    @cached_property
     def axis_name(self):
-        if self._axis_name is not None:
-            return self._axis_name
         an = {}
         for axi, ax in enumerate(self.axis_order):
             an[axi] = ax
             an[ax] = ax
             an[ax.capitalize()] = ax
-        self._axis_name = an
         return an
 
-    _axis_id = None
-
-    @property
+    @cached_property
     def axis_id(self):
-        if self._axis_id is not None:
-            return self._axis_id
         ai = {}
         for axi, ax in enumerate(self.axis_order):
             ai[ax] = ai[axi] = axi
-        self._axis_id = ai
         return ai
 
-    _image_axis_name = None
-
     @property
     def image_axis_name(self):
-        # Default
-        if self._image_axis_name is not None:
-            return self._image_axis_name
-        self._image_axis_name = rv = {}
+        rv = {}
         for i in range(3):
             rv[i] = (self.axis_name[self.x_axis[i]], self.axis_name[self.y_axis[i]])
             rv[self.axis_name[i]] = rv[i]
             rv[self.axis_name[i].capitalize()] = rv[i]
         return rv
 
-    _x_axis = None
-
-    @property
+    @cached_property
     def x_axis(self):
-        if self._x_axis is not None:
-            return self._x_axis
         ai = self.axis_id
         xa = {}
         for a1, a2 in self._x_pairs:
             xa[a1] = xa[ai[a1]] = ai[a2]
-        self._x_axis = xa
         return xa
 
-    _y_axis = None
-
-    @property
+    @cached_property
     def y_axis(self):
-        if self._y_axis is not None:
-            return self._y_axis
         ai = self.axis_id
         ya = {}
         for a1, a2 in self._y_pairs:
             ya[a1] = ya[ai[a1]] = ai[a2]
-        self._y_axis = ya
         return ya
 
     @property
-    @abc.abstractproperty
+    @abc.abstractmethod
     def period(self):
         pass
 
@@ -322,49 +285,11 @@ class CoordinateHandler(abc.ABC):
         return width
 
     def sanitize_center(self, center, axis):
-        if isinstance(center, str):
-            if center.lower() == "m" or center.lower() == "max":
-                v, center = self.ds.find_max(("gas", "density"))
-                center = self.ds.arr(center, "code_length")
-            elif center.lower() == "c" or center.lower() == "center":
-                # domain_left_edge and domain_right_edge might not be
-                # initialized until we create the index, so create it
-                self.ds.index
-                center = (self.ds.domain_left_edge + self.ds.domain_right_edge) / 2
-            else:
-                raise RuntimeError(f'center keyword "{center}" not recognized')
-        elif isinstance(center, YTArray):
-            return self.ds.arr(center), self.convert_to_cartesian(center)
-        elif is_sequence(center):
-            if isinstance(center[0], str) and isinstance(center[1], str):
-                if center[0].lower() == "min":
-                    v, center = self.ds.find_min(center[1])
-                elif center[0].lower() == "max":
-                    v, center = self.ds.find_max(center[1])
-                else:
-                    raise RuntimeError(f'center keyword "{center}" not recognized')
-                center = self.ds.arr(center, "code_length")
-            elif is_sequence(center[0]) and isinstance(center[1], str):
-                center = self.ds.arr(center[0], center[1])
-            else:
-                center = self.ds.arr(center, "code_length")
-        else:
-            raise RuntimeError(f'center keyword "{center}" not recognized')
+        center = parse_center_array(center, ds=self.ds, axis=axis)
         # This has to return both a center and a display_center
         display_center = self.convert_to_cartesian(center)
         return center, display_center
 
-    def sanitize_buffer_fill_values(self, buff):
-        """Replace nans with +inf in buff, if all valid values are positive"""
-        # In buffer with only positive values, maplotlib will raise a warning
-        # if nan is used as a filler, while it tolerates np.inf just fine
-        # This hack is however not necessary since Matpltolib 3.2
-        if MPL_VERSION >= Version("3.2"):
-            return
-        minval = buff[~np.isnan(buff)].min()
-        if minval >= 0:
-            buff[np.isnan(buff)] = np.inf
-
 
 def cartesian_to_cylindrical(coord, center=(0, 0, 0)):
     c2 = np.zeros_like(coord)
