@@ -24,21 +24,25 @@ from yt.funcs import is_sequence
 from yt.loaders import load
 from yt.units.yt_array import YTArray, YTQuantity
 
-# we import this in a weird way from numpy.testing to avoid triggering
-# flake8 errors from the unused imports. These test functions are imported
-# elsewhere in yt from here so we want them to be imported here.
-from numpy.testing import assert_array_equal, assert_almost_equal  # NOQA isort:skip
-from numpy.testing import assert_equal, assert_array_less  # NOQA isort:skip
-from numpy.testing import assert_string_equal  # NOQA isort:skip
-from numpy.testing import assert_array_almost_equal_nulp  # isort:skip
-from numpy.testing import assert_allclose, assert_raises  # NOQA isort:skip
-from numpy.testing import assert_approx_equal  # NOQA isort:skip
-from numpy.testing import assert_array_almost_equal  # NOQA isort:skip
-
 ANSWER_TEST_TAG = "answer_test"
+
+
 # Expose assert_true and assert_less_equal from unittest.TestCase
 # this is adopted from nose. Doing this here allows us to avoid importing
 # nose at the top level.
+def _deprecated_assert_func(func):
+    @wraps(func)
+    def retf(*args, **kwargs):
+        issue_deprecation_warning(
+            f"yt.testing.{func.__name__} is deprecated",
+            since="4.2",
+            stacklevel=3,
+        )
+        return func(*args, **kwargs)
+
+    return retf
+
+
 class _Dummy(unittest.TestCase):
     def nop(self):
         pass
@@ -46,11 +50,13 @@ class _Dummy(unittest.TestCase):
 
 _t = _Dummy("nop")
 
-assert_true = _t.assertTrue
-assert_less_equal = _t.assertLessEqual
+assert_true = _deprecated_assert_func(_t.assertTrue)
+assert_less_equal = _deprecated_assert_func(_t.assertLessEqual)
 
 
 def assert_rel_equal(a1, a2, decimals, err_msg="", verbose=True):
+    from numpy.testing import assert_almost_equal
+
     # We have nan checks in here because occasionally we have fields that get
     # weighted without non-zero weights.  I'm looking at you, particle fields!
     if isinstance(a1, np.ndarray):
@@ -299,6 +305,7 @@ _geom_transforms = {
     "polar": ((0.0, 0.0, 0.0), (1.0, 2.0 * np.pi, 1.0)),  # rtz
     "geographic": ((-90.0, -180.0, 0.0), (90.0, 180.0, 1000.0)),  # latlonalt
     "internal_geographic": ((-90.0, -180.0, 0.0), (90.0, 180.0, 1000.0)),  # latlondep
+    "spectral_cube": ((0.0, 0.0, 0.0), (1.0, 1.0, 1.0)),
 }
 
 
@@ -331,9 +338,12 @@ def fake_amr_ds(
         level, left_edge, right_edge, dims = gspec
         left_edge = left_edge * (RE - LE) + LE
         right_edge = right_edge * (RE - LE) + LE
-        gdata = dict(
-            level=level, left_edge=left_edge, right_edge=right_edge, dimensions=dims
-        )
+        gdata = {
+            "level": level,
+            "left_edge": left_edge,
+            "right_edge": right_edge,
+            "dimensions": dims,
+        }
         for f, u in zip(fields, units):
             gdata[f] = (prng.random_sample(dims), u)
         if particles:
@@ -591,7 +601,7 @@ def fake_vr_orientation_test_ds(N=96, scale=1):
         )
         arr[idx] = 0.6
 
-    data = dict(density=(arr, "g/cm**3"))
+    data = {"density": (arr, "g/cm**3")}
     ds = load_uniform_grid(data, arr.shape, bbox=bbox)
     return ds
 
@@ -833,6 +843,10 @@ def expand_keywords(keywords, full=False):
     ...     write_projection(*args, **kwargs)
     """
 
+    issue_deprecation_warning(
+        "yt.testing.expand_keywords is deprecated", since="4.2", stacklevel=2
+    )
+
     # if we want every possible combination of keywords, use iter magic
     if full:
         keys = sorted(keywords)
@@ -859,7 +873,7 @@ def expand_keywords(keywords, full=False):
         # the possible values of the kwargs
 
         # initialize array
-        list_of_kwarg_dicts = np.array([dict() for x in range(num_lists)])
+        list_of_kwarg_dicts = np.array([{} for x in range(num_lists)])
 
         # fill in array
         for i in np.arange(num_lists):
@@ -969,6 +983,8 @@ def disable_dataset_cache(func):
 
 @disable_dataset_cache
 def units_override_check(fn):
+    from numpy.testing import assert_equal
+
     units_list = ["length", "time", "mass", "velocity", "magnetic", "temperature"]
     ds1 = load(fn)
     units_override = {}
@@ -1110,7 +1126,9 @@ def check_results(func):
 
         return _func
 
-    from yt.mods import unparsed_args
+    import yt.startup_tasks as _startup_tasks
+
+    unparsed_args = _startup_tasks.unparsed_args
 
     if "--answer-reference" in unparsed_args:
         return compute_results(func)
@@ -1118,6 +1136,8 @@ def check_results(func):
     def compare_results(func):
         @wraps(func)
         def _func(*args, **kwargs):
+            from numpy.testing import assert_allclose, assert_equal
+
             name = kwargs.pop("result_basename", func.__name__)
             rv = func(*args, **kwargs)
             if hasattr(rv, "convert_to_base"):
@@ -1248,6 +1268,8 @@ def assert_allclose_units(actual, desired, rtol=1e-7, atol=0, **kwargs):
     function for details.
 
     """
+    from numpy.testing import assert_allclose
+
     # Create a copy to ensure this function does not alter input arrays
     act = YTArray(actual)
     des = YTArray(desired)
@@ -1256,8 +1278,8 @@ def assert_allclose_units(actual, desired, rtol=1e-7, atol=0, **kwargs):
         des = des.in_units(act.units)
     except UnitOperationError as e:
         raise AssertionError(
-            "Units of actual (%s) and desired (%s) do not have "
-            "equivalent dimensions" % (act.units, des.units)
+            f"Units of actual ({act.units}) and desired ({des.units}) "
+            "do not have equivalent dimensions"
         ) from e
 
     rt = YTArray(rtol)
@@ -1271,8 +1293,8 @@ def assert_allclose_units(actual, desired, rtol=1e-7, atol=0, **kwargs):
         at = at.in_units(act.units)
     except UnitOperationError as e:
         raise AssertionError(
-            "Units of atol (%s) and actual (%s) do not have "
-            "equivalent dimensions" % (at.units, act.units)
+            f"Units of atol ({at.units}) and actual ({act.units}) "
+            "do not have equivalent dimensions"
         ) from e
 
     # units have been validated, so we strip units before calling numpy
@@ -1311,12 +1333,9 @@ def assert_fname(fname):
 
     extension = os.path.splitext(fname)[1]
 
-    assert (
-        image_type == extension
-    ), "Expected an image of type '{}' but '{}' is an image of type '{}'".format(
-        extension,
-        fname,
-        image_type,
+    assert image_type == extension, (
+        f"Expected an image of type {extension!r} but {fname!r} "
+        "is an image of type {image_type!r}"
     )
 
 
@@ -1396,6 +1415,8 @@ class ParticleSelectionComparison:
         self.hsml = hsml
 
     def compare_dobj_selection(self, dobj):
+        from numpy.testing import assert_array_almost_equal_nulp
+
         for ptype in sorted(self.particles):
             x, y, z = self.particles[ptype].T
             # Set our radii to zero for now, I guess?
@@ -1492,3 +1513,73 @@ class ParticleSelectionComparison:
             (0.0 + LE[2], "unitary") : (0.1 + LE[2], "unitary"),
         ]
         self.compare_dobj_selection(reg3)
+
+
+def _deprecated_numpy_testing_reexport(func):
+    import numpy.testing as npt
+
+    npt_func = getattr(npt, func.__name__)
+
+    @wraps(npt_func)
+    def retf(*args, **kwargs):
+        __tracebackhide__ = True  # Hide traceback for pytest
+        issue_deprecation_warning(
+            f"yt.testing.{func.__name__} is a pure re-export of "
+            f"numpy.testing.{func.__name__}, it will stop working in the future. "
+            "Please import this function directly from numpy instead.",
+            since="4.2",
+            stacklevel=3,
+        )
+        return npt_func(*args, **kwargs)
+
+    return retf
+
+
+@_deprecated_numpy_testing_reexport
+def assert_array_equal():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_almost_equal():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_equal():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_array_less():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_string_equal():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_array_almost_equal_nulp():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_allclose():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_raises():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_approx_equal():
+    ...
+
+
+@_deprecated_numpy_testing_reexport
+def assert_array_almost_equal():
+    ...
