@@ -1,7 +1,8 @@
 from nose.tools import assert_raises
+from numpy.testing import assert_equal
 
 from yt.funcs import just_one, levenshtein_distance, validate_axis, validate_center
-from yt.testing import assert_equal, fake_amr_ds
+from yt.testing import fake_amr_ds
 from yt.units import YTArray, YTQuantity
 
 
@@ -16,11 +17,10 @@ def test_validate_axis():
         # default geometry is cartesian
         ds = fake_amr_ds()
         ds.slice("r", 0.25)
-    desired = (
-        "Expected axis of int or char type (can be "
-        "[0, 'x', 'X', 1, 'y', 'Y', 2, 'z', 'Z']), received 'r'."
-    )
-    assert_equal(str(ex.exception)[:40], desired[:40])
+    desired = "Expected axis to be any of [0, 1, 2, 'x', 'y', 'z', 'X', 'Y', 'Z'], received 'r'"
+
+    actual = str(ex.exception)
+    assert actual == desired
 
 
 def test_validate_center():
