@@ -10,10 +10,10 @@ import matplotlib.image as mpimg
 import numpy as np
 
 import yt.visualization.plot_window as pw
+from yt.utilities.answer_testing.framework import create_obj
 from yt.utilities.answer_testing.testing_utilities import (
     _create_phase_plot_attribute_plot,
     _create_plot_window_attribute_plot,
-    create_obj,
 )
 
 
@@ -87,10 +87,13 @@ def field_values(ds, field, obj_type=None, particle_type=False):
     # If needed build an instance of the dataset type
     obj = create_obj(ds, obj_type)
     determined_field = obj._determine_fields(field)[0]
+    fd = ds.field_info[determined_field]
     # Get the proper weight field depending on if we're looking at
     # particles or not
     if particle_type:
         weight_field = (determined_field[0], "particle_ones")
+    elif fd.is_sph_field:
+        weight_field = (determined_field[0], "ones")
     else:
         weight_field = ("index", "ones")
     # Get the average, min, and max
@@ -109,9 +112,9 @@ def pixelized_projection_values(ds, axis, field, weight_field=None, dobj_type=No
         obj = None
     proj = ds.proj(field, axis, weight_field=weight_field, data_source=obj)
     frb = proj.to_frb((1.0, "unitary"), 256)
-    frb[field]
+    frb.render(field)
     if weight_field is not None:
-        frb[weight_field]
+        frb.render(weight_field)
     d = frb.data
     for f in proj.field_data:
         # Sometimes f will be a tuple.
