@@ -1,14 +1,14 @@
 # We don't need to import 'exceptions'
 import os.path
-from typing import List, Tuple
+from typing import List
 
 from unyt.exceptions import UnitOperationError
 
+from yt._typing import FieldKey
+
 
 class YTException(Exception):
-    def __init__(self, message=None, ds=None):
-        Exception.__init__(self, message)
-        self.ds = ds
+    pass
 
 
 # Data access exceptions:
@@ -47,7 +47,7 @@ class YTAmbiguousDataType(YTUnidentifiedDataType):
 
 class YTSphereTooSmall(YTException):
     def __init__(self, ds, radius, smallest_cell):
-        YTException.__init__(self, ds=ds)
+        self.ds = ds
         self.radius = radius
         self.smallest_cell = smallest_cell
 
@@ -79,7 +79,7 @@ class YTFieldNotFound(YTException):
         self.field = field
         self.ds = ds
 
-    def _get_suggestions(self) -> List[Tuple[str, str]]:
+    def _get_suggestions(self) -> List[FieldKey]:
         from yt.funcs import levenshtein_distance
 
         field = self.field
@@ -127,7 +127,7 @@ class YTFieldNotFound(YTException):
         ]
 
     def __str__(self):
-        msg = f"Could not find field {self.field} in {self.ds}."
+        msg = f"Could not find field {self.field!r} in {self.ds}."
         try:
             suggestions = self._get_suggestions()
         except AttributeError:
@@ -176,7 +176,6 @@ class YTFieldTypeNotFound(YTException):
 
 class YTSimulationNotIdentified(YTException):
     def __init__(self, sim_type):
-        YTException.__init__(self)
         self.sim_type = sim_type
 
     def __str__(self):
@@ -219,7 +218,7 @@ class InvalidSimulationTimeSeries(YTException):
 
 class MissingParameter(YTException):
     def __init__(self, ds, parameter):
-        YTException.__init__(self, ds=ds)
+        self.ds = ds
         self.parameter = parameter
 
     def __str__(self):
@@ -228,7 +227,7 @@ class MissingParameter(YTException):
 
 class NoStoppingCondition(YTException):
     def __init__(self, ds):
-        YTException.__init__(self, ds=ds)
+        self.ds = ds
 
     def __str__(self):
         return f"Simulation {self.ds} has no stopping condition. StopTime or StopCycle should be set."
@@ -239,14 +238,6 @@ class YTNotInsideNotebook(YTException):
         return "This function only works from within an IPython Notebook."
 
 
-class YTGeometryNotSupported(YTException):
-    def __init__(self, geom):
-        self.geom = geom
-
-    def __str__(self):
-        return f"We don't currently support {self.geom!r} geometry"
-
-
 class YTCoordinateNotImplemented(YTException):
     def __str__(self):
         return "This coordinate is not implemented for this geometry type."
@@ -348,7 +339,7 @@ class YTCloudError(YTException):
 
 class YTEllipsoidOrdering(YTException):
     def __init__(self, ds, A, B, C):
-        YTException.__init__(self, ds=ds)
+        self.ds = ds
         self._A = A
         self._B = B
         self._C = C
@@ -409,7 +400,7 @@ class YTFieldNotParseable(YTException):
         self.field = field
 
     def __str__(self):
-        return f"Cannot identify field {self.field}"
+        return f"Cannot identify field {self.field!r}"
 
 
 class YTDataSelectorNotImplemented(YTException):
@@ -539,7 +530,7 @@ class YTElementTypeNotRecognized(YTException):
         return f"Element type not recognized - dim = {self.dim}, num_nodes = {self.num_nodes}"
 
 
-class YTDuplicateFieldInProfile(Exception):
+class YTDuplicateFieldInProfile(YTException):
     def __init__(self, field, new_spec, old_spec):
         self.field = field
         self.new_spec = new_spec
@@ -553,7 +544,7 @@ class YTDuplicateFieldInProfile(Exception):
         return r
 
 
-class YTInvalidPositionArray(Exception):
+class YTInvalidPositionArray(YTException):
     def __init__(self, shape, dimensions):
         self.shape = shape
         self.dimensions = dimensions
@@ -564,7 +555,7 @@ class YTInvalidPositionArray(Exception):
         return r
 
 
-class YTIllDefinedCutRegion(Exception):
+class YTIllDefinedCutRegion(YTException):
     def __init__(self, conditions):
         self.conditions = conditions
 
@@ -577,7 +568,7 @@ class YTIllDefinedCutRegion(Exception):
         return r
 
 
-class YTMixedCutRegion(Exception):
+class YTMixedCutRegion(YTException):
     def __init__(self, conditions, field):
         self.conditions = conditions
         self.field = field
@@ -590,7 +581,7 @@ class YTMixedCutRegion(Exception):
         return r
 
 
-class YTGDFAlreadyExists(Exception):
+class YTGDFAlreadyExists(YTException):
     def __init__(self, filename):
         self.filename = filename
 
@@ -613,7 +604,7 @@ class YTNonIndexedDataContainer(YTException):
         )
 
 
-class YTGDFUnknownGeometry(Exception):
+class YTGDFUnknownGeometry(YTException):
     def __init__(self, geometry):
         self.geometry = geometry
 
@@ -625,7 +616,7 @@ class YTGDFUnknownGeometry(Exception):
         )
 
 
-class YTInvalidUnitEquivalence(Exception):
+class YTInvalidUnitEquivalence(YTException):
     def __init__(self, equiv, unit1, unit2):
         self.equiv = equiv
         self.unit1 = unit1
@@ -635,7 +626,7 @@ class YTInvalidUnitEquivalence(Exception):
         return f"The unit equivalence {self.equiv!r} does not exist for the units {self.unit1!r} and {self.unit2!r}."
 
 
-class YTPlotCallbackError(Exception):
+class YTPlotCallbackError(YTException):
     def __init__(self, callback):
         self.callback = "annotate_" + callback
 
@@ -880,14 +871,14 @@ class YTCommandRequiresModule(YTException):
         return msg
 
 
-class YTModuleRemoved(Exception):
+class YTModuleRemoved(YTException):
     def __init__(self, name, new_home=None, info=None):
         message = f"The {name} module has been removed from yt."
         if new_home is not None:
             message += f"\nIt has been moved to {new_home}."
         if info is not None:
             message += f"\nFor more information, see {info}."
-        Exception.__init__(self, message)
+        super().__init__(message)
 
 
 class YTArrayTooLargeToDisplay(YTException):
@@ -909,7 +900,6 @@ class YTConfigurationError(YTException):
 class GenerationInProgress(Exception):
     def __init__(self, fields):
         self.fields = fields
-        super().__init__()
 
 
 class MountError(Exception):
