@@ -58,7 +58,7 @@ class CallbackWrapper:
             if viewer._has_swapped_axes:
                 # store the original un-transposed shape
                 self.raw_image_shape = self.raw_image_shape[1], self.raw_image_shape[0]
-        if frb.axis < 3:
+        if frb.axis is not None:
             DD = frb.ds.domain_width
             xax = frb.ds.coordinates.x_axis[frb.axis]
             yax = frb.ds.coordinates.y_axis[frb.axis]
@@ -130,7 +130,6 @@ class PlotMPL:
         self.axes = self.figure.add_axes(axrect)
 
     def _get_canvas_classes(self):
-
         if self.interactivity:
             key = str(matplotlib.get_backend())
         else:
@@ -286,14 +285,6 @@ class ImagePlotMPL(PlotMPL, ABC):
     def _init_image(self, data, extent, aspect):
         """Store output of imshow in image variable"""
 
-        if MPL_VERSION < Version("3.2"):
-            # with MPL 3.1 we use np.inf as a mask instead of np.nan
-            # this is done in CoordinateHandler.sanitize_buffer_fill_values
-            # however masking with inf is problematic here when we search for the max value
-            # so here we revert to nan
-            # see https://github.com/yt-project/yt/pull/2517 and https://github.com/yt-project/yt/pull/3793
-            data[~np.isfinite(data)] = np.nan
-
         norm = self.norm_handler.get_norm(data)
         extent = [float(e) for e in extent]
 
@@ -332,7 +323,7 @@ class ImagePlotMPL(PlotMPL, ABC):
             self.cb = self.figure.colorbar(self.image, self.cax)
         self.cax.tick_params(which="both", axis="y", direction="in")
 
-        fmt_kwargs = dict(style="scientific", scilimits=(-2, 3), useMathText=True)
+        fmt_kwargs = {"style": "scientific", "scilimits": (-2, 3), "useMathText": True}
         self.image.axes.ticklabel_format(**fmt_kwargs)
         if type(norm) not in (LogNorm, SymLogNorm):
             try:
@@ -346,13 +337,14 @@ class ImagePlotMPL(PlotMPL, ABC):
                         "with matplotlib versions older than 3.5\n"
                         "Please try upgrading matplotlib to a more recent version. "
                         "If the problem persists, please file a report to "
-                        "https://github.com/yt-project/yt/issues/new"
+                        "https://github.com/yt-project/yt/issues/new",
+                        stacklevel=2,
                     )
                 else:
                     raise exc
         if self.colorbar_handler.draw_minorticks:
             if isinstance(norm, SymLogNorm):
-                if Version("3.2.0") <= MPL_VERSION < Version("3.5.0b"):
+                if MPL_VERSION < Version("3.5.0b"):
                     # no known working method to draw symlog minor ticks
                     # see https://github.com/yt-project/yt/issues/3535
                     pass
@@ -414,7 +406,7 @@ class ImagePlotMPL(PlotMPL, ABC):
         # - self._draw_axes: bool
         # - self.colorbar_handler: ColorbarHandler
 
-        # optional attribtues
+        # optional attributes
         # - self._unit_aspect: float
 
         # Ensure the figure size along the long axis is always equal to _figure_size
