@@ -1,10 +1,11 @@
 import weakref
 from functools import partial
-from typing import TYPE_CHECKING, Dict, List, Optional, Tuple
+from typing import TYPE_CHECKING, Dict, List, Optional
 
 import numpy as np
 
 from yt._maintenance.deprecation import issue_deprecation_warning
+from yt._typing import FieldKey
 from yt.data_objects.image_array import ImageArray
 from yt.frontends.ytdata.utilities import save_as_dataset
 from yt.funcs import get_output_filename, iter_fields, mylog
@@ -13,7 +14,10 @@ from yt.utilities.lib.api import (  # type: ignore
     CICDeposit_2,
     add_points_to_greyscale_image,
 )
-from yt.utilities.lib.pixelization_routines import pixelize_cylinder
+from yt.utilities.lib.pixelization_routines import (
+    pixelize_cylinder,
+    rotate_particle_coord,
+)
 from yt.utilities.math_utils import compute_stddev_image
 from yt.utilities.on_demand_imports import _h5py as h5py
 
@@ -121,7 +125,7 @@ class FixedResolutionBuffer:
         # note that this import statement is actually crucial at runtime:
         # the filter methods for the present class are defined only when
         # fixed_resolution_filters is imported, so we need to guarantee
-        # that it happens no later than instanciation
+        # that it happens no later than instantiation
         from yt.visualization.fixed_resolution_filters import (
             FixedResolutionBufferFilter,
         )
@@ -135,7 +139,7 @@ class FixedResolutionBuffer:
             ds.plots.append(weakref.proxy(self))
 
         # Handle periodicity, just in case
-        if self.data_source.axis < 3:
+        if self.data_source.axis is not None:
             DLE = self.ds.domain_left_edge
             DRE = self.ds.domain_right_edge
             DD = float(self.periodic) * (DRE - DLE)
@@ -218,7 +222,7 @@ class FixedResolutionBuffer:
     def _get_info(self, item):
         info = {}
         ftype, fname = field = self.data_source._determine_fields(item)[0]
-        finfo = self.data_source.ds._get_field_info(*field)
+        finfo = self.data_source.ds._get_field_info(field)
         info["data_source"] = self.data_source.__str__()
         info["axis"] = self.data_source.axis
         info["field"] = str(item)
@@ -357,7 +361,7 @@ class FixedResolutionBuffer:
             fields = list(self.data.keys())
         output = h5py.File(filename, mode="a")
         for field in fields:
-            output.create_dataset(field, data=self[field])
+            output.create_dataset("_".join(field), data=self[field])
         output.close()
 
     def to_fits_data(self, fields=None, other_keys=None, length_unit=None, **kwargs):
@@ -530,7 +534,7 @@ class FixedResolutionBuffer:
 
     @property
     def limits(self):
-        rv = dict(x=None, y=None, z=None)
+        rv = {"x": None, "y": None, "z": None}
         xax = self.ds.coordinates.x_axis[self.axis]
         yax = self.ds.coordinates.y_axis[self.axis]
         xn = self.ds.coordinates.axis_name[xax]
@@ -623,12 +627,13 @@ class OffAxisProjectionFixedResolutionBuffer(FixedResolutionBuffer):
         )
         if self.data_source.moment == 2:
 
-            def _sq_field(field, data, item: Tuple[str, str]):
+            def _sq_field(field, data, item: FieldKey):
                 return data[item] ** 2
 
-            fd = self.ds._get_field_info(*item)
+            fd = self.ds._get_field_info(item)
+            ftype, fname = item
 
-            item_sq = (item[0], f"tmp_{item[1]}_squared")
+            item_sq = (ftype, f"tmp_{fname}_squared")
             self.ds.add_field(
                 item_sq,
                 partial(_sq_field, item=item),
@@ -685,11 +690,12 @@ class ParticleImageBuffer(FixedResolutionBuffer):
 
         # set up the axis field names
         axis = self.axis
-        self.xax = self.ds.coordinates.x_axis[axis]
-        self.yax = self.ds.coordinates.y_axis[axis]
-        ax_field_template = "particle_position_%s"
-        self.x_field = ax_field_template % self.ds.coordinates.axis_name[self.xax]
-        self.y_field = ax_field_template % self.ds.coordinates.axis_name[self.yax]
+        if axis is not None:
+            self.xax = self.ds.coordinates.x_axis[axis]
+            self.yax = self.ds.coordinates.y_axis[axis]
+            axis_name = self.ds.coordinates.axis_name
+            self.x_field = f"particle_position_{axis_name[self.xax]}"
+            self.y_field = f"particle_position_{axis_name[self.yax]}"
 
     def __getitem__(self, item):
         if item in self.data:
@@ -706,20 +712,39 @@ class ParticleImageBuffer(FixedResolutionBuffer):
             deposition,
         )
 
-        bounds = []
-        for b in self.bounds:
-            if hasattr(b, "in_units"):
-                b = float(b.in_units("code_length"))
-            bounds.append(b)
+        dd = self.data_source.dd
 
         ftype = item[0]
-        x_data = self.data_source.dd[ftype, self.x_field]
-        y_data = self.data_source.dd[ftype, self.y_field]
-        data = self.data_source.dd[item]
+        if self.axis is None:
+            wd = []
+            for w in self.data_source.width:
+                if hasattr(w, "to_value"):
+                    w = w.to_value("code_length")
+                wd.append(w)
+            x_data, y_data, *bounds = rotate_particle_coord(
+                dd[ftype, "particle_position_x"].to_value("code_length"),
+                dd[ftype, "particle_position_y"].to_value("code_length"),
+                dd[ftype, "particle_position_z"].to_value("code_length"),
+                self.data_source.center.to_value("code_length"),
+                wd,
+                self.data_source.normal_vector,
+                self.data_source.north_vector,
+            )
+            x_data = np.array(x_data)
+            y_data = np.array(y_data)
+        else:
+            bounds = []
+            for b in self.bounds:
+                if hasattr(b, "to_value"):
+                    b = b.to_value("code_length")
+                bounds.append(b)
+            x_data = dd[ftype, self.x_field].to_value("code_length")
+            y_data = dd[ftype, self.y_field].to_value("code_length")
+        data = dd[item]
 
         # handle periodicity
-        dx = x_data.in_units("code_length").d - bounds[0]
-        dy = y_data.in_units("code_length").d - bounds[2]
+        dx = x_data - bounds[0]
+        dy = y_data - bounds[2]
         if self.periodic:
             dx %= float(self._period[0].in_units("code_length"))
             dy %= float(self._period[1].in_units("code_length"))
@@ -737,7 +762,7 @@ class ParticleImageBuffer(FixedResolutionBuffer):
         if weight_field is None:
             weight_data = np.ones_like(data.v)
         else:
-            weight_data = self.data_source.dd[weight_field]
+            weight_data = dd[weight_field]
         splat_vals = weight_data[mask] * data[mask]
 
         x_bin_edges = np.linspace(0.0, 1.0, self.buff_size[0] + 1)
@@ -780,8 +805,6 @@ class ParticleImageBuffer(FixedResolutionBuffer):
         else:
             units = data.units
 
-        ia = ImageArray(buff, units=units, info=info)
-
         # divide by the weight_field, if needed
         if weight_field is not None:
             weight_buff = np.zeros(self.buff_size)
@@ -801,15 +824,12 @@ class ParticleImageBuffer(FixedResolutionBuffer):
                     y_bin_edges,
                     x_bin_edges,
                 )
-            weight_array = ImageArray(
-                weight_buff, units=weight_data.units, info=self._get_info(item)
-            )
             # remove values in no-particle region
             weight_buff[weight_buff_mask == 0] = np.nan
-            locs = np.where(weight_array > 0)
-            ia[locs] /= weight_array[locs]
+            locs = np.where(weight_buff > 0)
+            buff[locs] /= weight_buff[locs]
 
-        self.data[item] = ia
+        self.data[item] = ImageArray(buff, units=units, info=info)
         return self.data[item]
 
     # over-ride the base class version, since we don't want to exclude
