@@ -117,7 +117,6 @@ class Camera(ParallelAnalysisInterface):
     Examples
     --------
 
-    >>> from yt.mods import *
     >>> import yt.visualization.volume_rendering.api as vr
 
     >>> ds = load("DD1701")  # Load a dataset
@@ -204,7 +203,7 @@ class Camera(ParallelAnalysisInterface):
         dd = self.ds.all_data()
         efields = dd._determine_fields(self.fields)
         if self.log_fields is None:
-            self.log_fields = [self.ds._get_field_info(*f).take_log for f in efields]
+            self.log_fields = [self.ds._get_field_info(f).take_log for f in efields]
         self.no_ghost = no_ghost
         self.use_light = use_light
         self.light_dir = None
@@ -801,14 +800,8 @@ class Camera(ParallelAnalysisInterface):
 
     def save_image(self, image, fn=None, clip_ratio=None, transparent=False):
         if self.comm.rank == 0 and fn is not None:
-            if transparent:
-                image.write_png(
-                    fn, clip_ratio=clip_ratio, rescale=True, background=None
-                )
-            else:
-                image.write_png(
-                    fn, clip_ratio=clip_ratio, rescale=True, background="black"
-                )
+            background = None if transparent else "black"
+            image.write_png(fn, rescale=True, background=background)
 
     def initialize_source(self):
         return self.volume.initialize_source(
@@ -1478,7 +1471,6 @@ def corners(left_edge, right_edge):
 
 
 class HEALpixCamera(Camera):
-
     _sampler_object = None
 
     def __init__(
@@ -1710,7 +1702,7 @@ class FisheyeCamera(Camera):
         fields = dd._determine_fields(fields)
         self.fields = fields
         if log_fields is None:
-            log_fields = [self.ds._get_field_info(*f).take_log for f in fields]
+            log_fields = [self.ds._get_field_info(f).take_log for f in fields]
         self.log_fields = log_fields
         self.sub_samples = sub_samples
         if volume is None:
@@ -1807,7 +1799,6 @@ class MosaicCamera(Camera):
         preload=True,
         use_light=False,
     ):
-
         ParallelAnalysisInterface.__init__(self)
 
         self.procs_per_wg = procs_per_wg
@@ -1928,7 +1919,6 @@ class MosaicCamera(Camera):
         self.width = owidth
 
     def snapshot(self, fn=None, clip_ratio=None, double_check=False, num_threads=0):
-
         my_storage = {}
         offx, offy = np.meshgrid(range(self.nimx), range(self.nimy))
         offxy = zip(offx.ravel(), offy.ravel())
@@ -2046,7 +2036,6 @@ class ProjectionCamera(Camera):
         interpolated=False,
         method="integrate",
     ):
-
         if not interpolated:
             volume = 1
 
@@ -2151,7 +2140,7 @@ class ProjectionCamera(Camera):
         ds = self.ds
         dd = ds.all_data()
         field = dd._determine_fields([self.field])[0]
-        finfo = ds._get_field_info(*field)
+        finfo = ds._get_field_info(field)
         dl = 1.0
         if self.method == "integrate":
             if self.weight is None:
@@ -2189,7 +2178,7 @@ class ProjectionCamera(Camera):
         # Now we have a bounding box.
         data_source = ds.region(self.center, mi, ma)
 
-        for (grid, mask) in data_source.blocks:
+        for grid, mask in data_source.blocks:
             data = [(grid[field] * mask).astype("float64") for field in fields]
             pg = PartitionedGrid(
                 grid.id,
@@ -2208,7 +2197,7 @@ class ProjectionCamera(Camera):
     def save_image(self, image, fn=None, clip_ratio=None):
         dd = self.ds.all_data()
         field = dd._determine_fields([self.field])[0]
-        finfo = self.ds._get_field_info(*field)
+        finfo = self.ds._get_field_info(field)
         if finfo.take_log:
             im = np.log10(image)
         else:
@@ -2220,7 +2209,6 @@ class ProjectionCamera(Camera):
                 write_image(im, fn)
 
     def snapshot(self, fn=None, clip_ratio=None, double_check=False, num_threads=0):
-
         if num_threads is None:
             num_threads = get_num_threads()
 
@@ -2400,7 +2388,6 @@ class StereoSphericalCamera(Camera):
         num_threads=0,
         transparent=False,
     ):
-
         if num_threads is None:
             num_threads = get_num_threads()
 
