@@ -1,9 +1,8 @@
 import abc
-import sys
 import warnings
 from functools import wraps
 from types import ModuleType
-from typing import Optional, Union
+from typing import Literal, Optional, Union
 
 import numpy as np
 
@@ -40,11 +39,6 @@ from .utils import (
 )
 from .zbuffer_array import ZBuffer
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 OptionalModule = Union[ModuleType, NotAModule]
 mesh_traversal: OptionalModule = NotAModule("pyembree")
 mesh_construction: OptionalModule = NotAModule("pyembree")
@@ -78,8 +72,10 @@ def set_raytracing_engine(
 
     if engine == "embree":
         try:
-            from yt.utilities.lib.embree_mesh import mesh_construction  # type: ignore
-            from yt.utilities.lib.embree_mesh import mesh_traversal  # type: ignore
+            from yt.utilities.lib.embree_mesh import (  # type: ignore
+                mesh_construction,
+                mesh_traversal,
+            )
         except (ImportError, ValueError) as exc:
             # Catch ValueError in case size of objects in Cython change
             warnings.warn(
@@ -333,7 +329,7 @@ class VolumeSource(RenderSource, abc.ABC):
         """The field to be rendered"""
         return self._field
 
-    @field.setter  # type: ignore
+    @field.setter
     @invalidate_volume
     def field(self, value):
         field = self.data_source._determine_fields(value)
@@ -359,7 +355,7 @@ class VolumeSource(RenderSource, abc.ABC):
         """Whether or not the field rendering is computed in log space"""
         return self._log_field
 
-    @log_field.setter  # type: ignore
+    @log_field.setter
     @invalidate_volume
     def log_field(self, value):
         self.transfer_function = None
@@ -372,7 +368,7 @@ class VolumeSource(RenderSource, abc.ABC):
         values at grid boundaries"""
         return self._use_ghost_zones
 
-    @use_ghost_zones.setter  # type: ignore
+    @use_ghost_zones.setter
     @invalidate_volume
     def use_ghost_zones(self, value):
         self._use_ghost_zones = value
@@ -385,7 +381,7 @@ class VolumeSource(RenderSource, abc.ABC):
         """
         return self._weight_field
 
-    @weight_field.setter  # type: ignore
+    @weight_field.setter
     @invalidate_volume
     def weight_field(self, value):
         self._weight_field = value
@@ -1291,7 +1287,6 @@ class BoxSource(LineSource):
     """
 
     def __init__(self, left_edge, right_edge, color=None):
-
         assert left_edge.shape == (3,)
         assert right_edge.shape == (3,)
 
